# --8<--8<--8<--8<--
#
# Copyright (C) 2009 Smithsonian Astrophysical Observatory
#
# This file is part of mst-cpan
#
# mst-cpan is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# mst-cpan is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the 
#       Free Software Foundation, Inc. 
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--

package MST::CPAN::Handler::Tcl;

use strict;
use warnings;

use base 'MST::CPAN::Handler';

sub init
{
    my $self = shift;

    # figure out where and what versions of tcl are available
    # use the TCL_VERSION macro in whatever tcl.h we can find.

    my %ver;
    for my $dir ( qw[ /usr /usr/local /opt/local ] )
    {
	for my $inc ( grep { -e $_ } <$dir/include/tcl.h>, <$dir/include/tcl*/tcl.h> )
	{
	    my ( $version ) =
	      $self->slurp( $inc ) =~ /TCL_VERSION\s+"([\d\.]+)"/s ;

	    $inc =~ s{/tcl.h$}{};

	    $ver{$version} = [ $dir, $inc ]
	      if defined $version;
	}

    }

    die( "can't find tcl.h anywhere\n" )
      unless keys %ver;

    my ( $version ) = sort { $b <=> $a } keys %ver;

    my ( $dir, $include )  = @{$ver{$version}};


    $self->makepl_arg( '--nousestubs',
		       "--include='-I$include'",
		       "--library='-L$dir/lib -ltcl$version'",
		     );

    $self->SUPER::init( @_ );
}

1;
